<?php

namespace App\Models\Service;

use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\MorphOne;

use App\Interfaces\ServiceItem;
use App\Models\Base\ServiceType;
use App\Models\Service;
use App\Traits\NextKey;

class Adsl extends ServiceType implements ServiceItem
{
	use NextKey;
	const RECORD_ID = 'service__adsl';

	protected $dates = [
		'service_connect_date',
		'service_contract_date'
	];
	protected $table = 'ab_service__adsl';

	/** SCOPES */

	/**
	 * Search for a record
	 *
	 * @param        $query
	 * @param string $term
	 * @return
	 */
	public function scopeSearch($query,string $term)
	{
		// Build our where clause
		return parent::scopeSearch($query,$term)
			->orwhere('service_number','like','%'.$term.'%')
			->orWhere('service_address','like','%'.$term.'%')
			->orWhere('ipaddress','like','%'.$term.'%');
	}

	/** ATTRIBUTES **/

	/**
	 * @deprecated use $o->type()->service_name;
	 * @return mixed|string
	 */
	public function getNameAttribute()
	{
		return $this->service_number ?: $this->service_address;
	}

	/**
	 * Return the service address
	 *
	 * @return string
	 */
	public function getServiceDescriptionAttribute(): string
	{
		return strtoupper($this->service_address) ?: 'NO Service Address';
	}

	/**
	 * Return the service number
	 *
	 * @return string
	 */
	public function getServiceNameAttribute(): string
	{
		return $this->service_number ?: 'NO Service Number';
	}

	/**
	 * Is this service currently in a contract
	 *
	 * @return bool
	 */
	public function inContract(): bool
	{
		return $this->service_contract_date AND $this->service_contract_date->addMonths($this->contract_term)->isFuture();
	}
}